@@ -36,8 +36,12 @@ class DeviceSession(Device):
     def __init__(self, device_id=None, config=None):
         kamzik3.session = self
         self.devices = OrderedDict()
-        self.server = config.get("server")
-        self.publisher = config.get("publisher")
+        if config is None:
+            self.server = None
+            self.publisher = None
+        else:
+            self.server = config.get("server")
+            self.publisher = config.get("publisher")
         self.measurement_groups = {}
         self.polling_timer = CallbackTimer(1000, self.measure_cpu_ram)
         self.os_process = psutil.Process(os.getpid())
