@@ -338,8 +338,7 @@ class MacroStepWidget(Ui_Form, MacroWidget):
                         values["wait_after"]).to("s"),
                         retry_count=self.config.get("retry_count", 0) if self.user_mode == MODE_SIMPLE else int(
                             values["retry_count"].m),
-                        trigger_log=self.config.get("trigger_log",
-                                                    True) if self.user_mode == MODE_SIMPLE else self.checkbox_log.isChecked(),
+                        trigger_log=self.checkbox_log.isChecked() if self.user_mode == MODE_ALL else self.config.get("trigger_log",True),
                         on_warning=self.config.get("on_warning", "Abort macro") if self.user_mode == MODE_SIMPLE else
                         values["on_warning"],
                         timeout=units.Quantity(self.config.get("timeout", "0s") if self.user_mode == MODE_SIMPLE else values[
@@ -357,8 +356,7 @@ class MacroStepWidget(Ui_Form, MacroWidget):
                         values["wait_after"]).to("s"),
                         retry_count=self.config.get("retry_count", 0) if self.user_mode == MODE_SIMPLE else int(
                             values["retry_count"].m),
-                        trigger_log=self.config.get("trigger_log",
-                                                    True) if self.user_mode == MODE_SIMPLE else self.checkbox_log.isChecked(),
+                        trigger_log=self.checkbox_log.isChecked() if self.user_mode == MODE_ALL else self.config.get("trigger_log", True),
                         on_warning=self.config.get("on_warning", "Abort macro") if self.user_mode == MODE_SIMPLE else
                         values["on_warning"],
                         timeout=units.Quantity(self.config.get("timeout", "0s") if self.user_mode == MODE_SIMPLE else values[
@@ -384,19 +382,18 @@ class MacroStepWidget(Ui_Form, MacroWidget):
                         values["retry_count"].m),
                     busy_timeout=units.Quantity(self.config.get("busy_timeout", "1000ms") if self.user_mode == MODE_SIMPLE else
                     values["busy_timeout"]).to("ms"),
-                    trigger_log=self.config.get("trigger_log",
-                                                True) if self.user_mode == MODE_SIMPLE else self.checkbox_log.isChecked(),
+                    trigger_log=self.checkbox_log.isChecked() if self.user_mode == MODE_ALL else self.config.get("trigger_log", True),
                     on_warning=self.config.get("on_warning", "Abort macro") if self.user_mode == MODE_SIMPLE else
                     values["on_warning"],
                     timeout=units.Quantity(self.config.get("timeout", "0s") if self.user_mode == MODE_SIMPLE else values[
                         "timeout"]).to("s")
                 )
-            # if self.config.get("scanner", "None") != "None":
-            #     scanner = kamzik3.session.get_device(self.config["scanner"])
-            #     scanner_attributes = {}
-            #     for attribute in scanner.get_scanner_attributes():
-            #         scanner_attributes[attribute] = self.macro_inputs[attribute].get_attribute_value()
-            #     step = scanner.get_scanner_macro(scanner_input=step, scanner_attributes=scanner_attributes)
+            if self.config.get("scanner", "None") != "None":
+                scanner = kamzik3.session.get_device(self.config["scanner"])
+                scanner_attributes = {}
+                for attribute in scanner.get_scanner_attributes():
+                    scanner_attributes[attribute] = self.macro_inputs[attribute].get_attribute_value()
+                step = scanner.get_scanner_macro(scanner_input=step, scanner_attributes=scanner_attributes)
             return step
         except KeyError:
             raise KeyError("One of attributes for {} were not set".format(self.title))
